@@ -22,7 +22,7 @@
 #include "effect.h"
 
 class QGraphicsDropShadowEffect;
-class QGraphicsItem;
+class GraphicsElement;
 
 class DropshadowEffect : public Effect
 {
@@ -30,7 +30,7 @@ public:
     enum Attribute {RADIUS, COLOR, XOFFSET, YOFFSET, ATTRIBUTE_COUNT};
     DropshadowEffect();
     virtual bool setAttribute(QString const& name, QString const& value);
-    virtual void apply(QGraphicsItem* item);
+    virtual void apply(GraphicsElement* item);
 
 private:
     QGraphicsDropShadowEffect* effect_;
