@@ -31,7 +31,7 @@ class GraphicsScene;
 class ImageElement : public GraphicsElement
 {
 public:
-    enum Attribute {XPOS, YPOS, ZPOS, SRC, WIDTH, HEIGHT, ATTRIBUTE_COUNT};
+    enum Attribute {XPOS, YPOS, ZPOS, VISIBLEWHEN, SRC, WIDTH, HEIGHT, ATTRIBUTE_COUNT};
     ImageElement(Reader* reader);
     virtual bool setAttribute(QString const& name, QString const& value);
     virtual void addToScene(GraphicsScene* scene);
