@@ -20,34 +20,10 @@
 #include <QtGui/QApplication>
 #include "mainwindow.h"
 
-#include "poiascreader.h"
-#include <QtCore/QDebug>
-#include "poialerts.h"
-
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
 
-   /* PoiAscReader reader("/home/maemo/workspace/jspeed/test.asc");
-
-    QList<PoiAscReader::Poi> pois;
-
-    if(reader.read(pois))
-    {
-        qDebug() << "Kyl";
-
-       for(int i = 0; i < pois.size(); i++)
-        {
-            qDebug() << pois.at(i).latitude << pois.at(i).longitude << pois.at(i).name;
-        }
-    }
-    else
-    {
-        qDebug() << "Ei";
-    }*/
-
-    //PoiAlerts::instance().startTest();
-
     MainWindow window;
 
     QObject::connect(&window, SIGNAL(quit()), &app, SLOT(quit()));
