@@ -39,7 +39,7 @@ speedAlarmSettings_(0), aboutDialog_(0)
     addAction(tr("Reset trip"), this, SIGNAL(resetTrip()));
     addAction(tr("Reset all"), this, SLOT(confirmReset()));
     addAction(tr("Theme"), this, SLOT(selectTheme()));
-    addAction(tr("Set unit"), this, SLOT(selectUnit()));
+    addAction(tr("Options"), this, SLOT(selectUnit()));
     addAction(tr("Speed camera alerts"), this, SLOT(openPoiAlerts()));
     addAction(tr("Speed alarm"), this, SLOT(openSpeedAlarm()));
     addAction(tr("Flip screen"), this, SIGNAL(flip()));
@@ -83,6 +83,7 @@ void MainMenu::selectUnit()
     {
         unitSelector_ = new UnitSelector(this);
         connect(unitSelector_, SIGNAL(unitChanged()), this, SIGNAL(unitChanged()));
+        connect(unitSelector_, SIGNAL(orientationChanged()), this, SIGNAL(orientationChanged()));
     }
 
     unitSelector_->show();
