@@ -33,6 +33,7 @@ public:
 
 signals:
     void unitChanged();
+    void orientationChanged();
 
 private slots:
     void saveUnit();
@@ -40,6 +41,8 @@ private slots:
 private:
     ButtonSelector* selector_;
     QString unit_;
+    ButtonSelector* orientationSelector_;
+    QString orientation_;
 };
 
 #endif
